==> hyades.source_1.1.0_20030930_2244.zip: org/eclipse/hyades/execution/security/SecureClient.java <==
package org.eclipse.hyades.execution.security;
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

import java.io.IOException;
import java.security.NoSuchAlgorithmException;
import java.security.Security;

import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSession;
import javax.net.ssl.SSLSocket;

/**
 * @author rduggan
 *
 * To change the template for this generated type comment go to
 * Window>Preferences>Java>Code Generation>Code and Comments
 */
public final class SecureClient {
	private SSLSocket sslsocket;

	private IKeystoreManager loadKeystore(ISecureClientParameters params) 
		 throws java.security.KeyStoreException, 
		        java.security.NoSuchAlgorithmException,
		        java.security.UnrecoverableKeyException,
		        java.security.KeyManagementException,
		        java.security.cert.CertificateException,
		        java.io.IOException
	{
		IKeystoreManager manager=params.getKeystoreManager();
		manager.setProvider(params.getSecurityProvider());
		manager.loadKeystore(params.getKeystoreFileName(), params.getKeystoreFilepassword()); 
		return manager;
	}


	public void init(ISecureClientParameters params, String host, int port) 
		throws java.security.KeyStoreException, 
				java.security.NoSuchAlgorithmException,
				java.security.UnrecoverableKeyException,
				java.security.KeyManagementException,
				java.security.cert.CertificateException,
				java.io.IOException{
		int protocolOffset = 0;
		IKeystoreManager keyManager=null;
		
		System.out.println("Secure Client initialization started");
		/* add the proper security provider */
		Security.addProvider(params.getSecurityProvider());
		
		
		/* Load our keystore */
		keyManager=loadKeystore(params);
		
		
		/* Setup our SSLContext */
		SSLContext sslContext=null;
		String[] sslProtocols = params.getEnabledProtocols();
		do {
		
			try {
				sslContext=SSLContext.getInstance(sslProtocols[protocolOffset]/*, params.getSecurityProvider()*/);
				break;
			}
			catch(NoSuchAlgorithmException e) {
				protocolOffset++;
				if(protocolOffset==sslProtocols.length) {
					throw e;		
				}		
			}		
		}while(protocolOffset<sslProtocols.length);
			
		/* Initailize our context with the specified key and trust managers */
		sslContext.init(keyManager.getKeyManagers(), keyManager.getTrustManagers(), null);

		
		/* Create out Secure socket to connect to server on the specified host and port. */
		sslsocket=(SSLSocket)sslContext.getSocketFactory().createSocket(host, port);
		

		/* Use the cypher suites specified */
		sslsocket.setEnabledCipherSuites(params.getEnabledCipherSuites());
		
		/* Start the handshake with the server */
        sslsocket.startHandshake();
        
        /* Get the sesson to ensure the connection is complete */
        SSLSession session = sslsocket.getSession();	
		if (session == null) {
			System.out.println("Session is null. Socket connection failed");
			throw new IOException("No socket session created");
		}
		else {
			System.out.println("Secure Client initialization completed");
		}
	}

	public SSLSocket getSocket() {
		return sslsocket;
	}
	
}

==> hyades.source_3.3.0_20050623_2150.zip: org/eclipse/hyades/execution/security/SecureClient.java <==
package org.eclipse.hyades.execution.security;
/**********************************************************************
 * Copyright (c) 2005 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * $Id: SecureClient.java,v 1.5 2005/05/09 01:35:17 jptoomey Exp $
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

import java.io.IOException;
import java.security.NoSuchAlgorithmException;
import java.security.Security;

import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSession;
import javax.net.ssl.SSLSocket;

/**
 * @author rduggan
 *
 * To change the template for this generated type comment go to
 * Window>Preferences>Java>Code Generation>Code and Comments
 */
public final class SecureClient {
	private SSLSocket sslsocket;

	private IKeystoreManager loadKeystore(ISecureClientParameters params) 
		 throws java.security.KeyStoreException, 
		        java.security.NoSuchAlgorithmException,
		        java.security.UnrecoverableKeyException,
		        java.security.KeyManagementException,
		        java.security.cert.CertificateException,
		        java.io.IOException
	{
		IKeystoreManager manager=params.getKeystoreManager();
		manager.setProvider(params.getSecurityProvider());
		manager.loadKeystore(params.getKeystoreFileName(), params.getKeystoreFilepassword()); 
		return manager;
	}


	public void init(ISecureClientParameters params, String host, int port) 
		throws java.security.KeyStoreException, 
				java.security.NoSuchAlgorithmException,
				java.security.UnrecoverableKeyException,
				java.security.KeyManagementException,
				java.security.cert.CertificateException,
				java.io.IOException{
		int protocolOffset = 0;
		IKeystoreManager keyManager=null;
		
		/* add the proper security provider */
		Security.addProvider(params.getSecurityProvider());
		
		
		/* Load our keystore */
		keyManager=loadKeystore(params);
		
		
		/* Setup our SSLContext */
		SSLContext sslContext=null;
		String[] sslProtocols = params.getEnabledProtocols();
		do {
		
			try {
				sslContext=SSLContext.getInstance(sslProtocols[protocolOffset]/*, params.getSecurityProvider()*/);
				break;
			}
			catch(NoSuchAlgorithmException e) {
				protocolOffset++;
				if(protocolOffset==sslProtocols.length) {
					throw e;		
				}		
			}		
		}while(protocolOffset<sslProtocols.length);
			
		/* Initailize our context with the specified key and trust managers */
		sslContext.init(keyManager.getKeyManagers(), keyManager.getTrustManagers(), null);

		
		/* Create out Secure socket to connect to server on the specified host and port. */
		sslsocket=(SSLSocket)sslContext.getSocketFactory().createSocket(host, port);
		

		/* Use the cypher suites specified */
		sslsocket.setEnabledCipherSuites(params.getEnabledCipherSuites());
		
		/* Start the handshake with the server */
        sslsocket.startHandshake();
        
        /* Get the sesson to ensure the connection is complete */
        SSLSession session = sslsocket.getSession();	
		if (session == null) {
			System.out.println("Session is null. Socket connection failed");
			throw new IOException("No socket session created");
		}
	}

	public SSLSocket getSocket() {
		return sslsocket;
	}
	
}
